@@ -11,9 +11,7 @@ from ...utils import needs_py310
 @pytest.fixture(
     name="client",
     params=[
-        pytest.param("tutorial010_py39"),
         pytest.param("tutorial010_py310", marks=needs_py310),
-        pytest.param("tutorial010_an_py39"),
         pytest.param("tutorial010_an_py310", marks=needs_py310),
     ],
 )
